@@ -16,7 +16,7 @@ use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.0.8');
+our $VERSION = version->new('0.0.9');
 
 my $opt = Getopt::Alt->new(
     {
@@ -65,11 +65,10 @@ sub since_release {
     elsif (!@tags) {
         return;
     }
-    warn join ', ', @tags, "\n";
 
     my ($sha, $time) = split /\s+/, `git log -n 1 --format=format:'%H %at' $tags[-1]`;
 
-    my $format = @ARGV ? join(' ', @ARGV) : '--format=format"  %s"';
+    my $format = @ARGV ? join(' ', @ARGV) : '--format=format:"  %s"';
     my @logged = `git log -n 100 $format $sha..HEAD`;
 
     if ($opt->opt->released) {
@@ -94,7 +93,7 @@ Group::Git::Cmd::SinceRelease - Gets the number of commits each repository is ah
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.8
+This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.9
 
 =head1 SYNOPSIS
 
